<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/point/goods/list',
        canEdit: (row) => row.status === 'I',
        canDelete: (row) => row.status === 'I',
        columns: [
          { label: '', type: 'selection' },
          { label: '序号', type: 'index' },
          {
            label: '商品图片',
            formatter: (row) =>
              row.cover ? (
                <el-bus-image
                  src={row.cover}
                  lazy={true}
                  style="width:50px;height:50px"
                ></el-bus-image>
              ) : null,
          },
          { label: '商品名称', prop: 'name' },
          { label: '状态', prop: 'statusStr' },
          { label: '库存', prop: 'stock' },
          { label: '所需积分', prop: 'point' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                label: '商品名称',
                id: 'name',
                type: 'input',
              },
              {
                label: '状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  code: 'POINT_GOODS_STATUS',
                  style: 'width:100%',
                  clearable: true,
                },
              },
            ],
          },
        ],
        form: [
          {
            label: '商品名称：',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入商品名称',
              trigger: 'blur',
            },
          },
          {
            label: '商品规格信息：',
            id: 'description',
            type: 'input',
            el: {
              type: 'textarea',
              rows: 4,
            },
            rules: {
              required: true,
              message: '请输入商品规格信息',
              trigger: 'blur',
            },
          },
          {
            label: '库存：',
            id: 'stock',
            type: 'input-number',
            el: {
              precision: 0,
              min: 0,
              max: 99999999,
              controls: false,
            },
            rules: [
              { required: true, message: '请输入库存', trigger: 'blur' },
              {
                type: 'number',
                min: 1,
                message: '库存必须大于0',
                trigger: 'blur',
              },
            ],
          },
          {
            label: '商品图片：',
            id: 'cover',
            type: 'bus-upload',
            el: {
              listType: 'picture-card',
              limit: 1,
              limitSize: 2,
              tipText: '大小不超过2M',
              valueType: 'string',
            },
            forceDisabled: true,
            rules: {
              required: true,
              message: '请上传商品图片',
              trigger: 'blur',
            },
          },
          {
            label: '积分数量：',
            id: 'point',
            type: 'input-number',
            el: {
              precision: 0,
              min: 1,
              max: 99999999,
              controls: false,
            },
            rules: {
              required: true,
              message: '请输入积分数量',
              trigger: 'blur',
            },
          },
        ],
        extraButtons: [
          {
            text: '上架',
            show: (row) => row.status === 'I' && row.stock > 0,
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要上架吗？')
                const { code } = await this.$elBusHttp.request(
                  'flower/api/point/goods/list/on',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success('上架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '下架',
            show: (row) => row.status === 'A',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要下架吗？')
                const { code } = await this.$elBusHttp.request(
                  'flower/api/point/goods/list/off',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        headerButtons: [
          {
            text: '批量上架',
            type: 'primary',
            disabled: (selected) =>
              selected.filter((i) => i.status === 'I').length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter((i) => i.status === 'I')
                await this.$elBusUtil.confirm(
                  `确定要上架这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/point/goods/list/on',
                  { params: { id: items.map((i) => i.id).join(',') } }
                )
                if (code === 0) {
                  this.$message.success('上架成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量下架',
            type: 'primary',
            disabled: (selected) =>
              selected.filter((i) => i.status === 'A').length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter((i) => i.status === 'A')
                await this.$elBusUtil.confirm(
                  `确定要下架这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/point/goods/list/off',
                  { params: { id: items.map((i) => i.id).join(',') } }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量删除',
            type: 'danger',
            disabled: (selected) =>
              selected.filter((i) => i.status === 'I').length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter((i) => i.status === 'I')
                await this.$elBusUtil.confirm(
                  `确定要删除这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/point/goods/list/delete',
                  { params: { id: items.map((i) => i.id).join(',') } }
                )
                if (code === 0) {
                  this.$message.success('删除成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '积分商品',
    }
  },
}
</script>
